@@ -31,10 +31,6 @@
         <source>Error registering documentation file &apos;%1&apos;: %2</source>
         <translation>Beim Registrieren der Dokumentationsdatei &apos;%1&apos; trat ein Fehler auf: %2</translation>
     </message>
-    <message>
-        <source>Error: %1</source>
-        <translation>Fehler: %1</translation>
-    </message>
     <message>
         <source>Could not register documentation file
 %1
@@ -257,8 +253,8 @@ Grund:
         <translation>Adresse</translation>
     </message>
     <message>
-        <source>Toolbar Menu</source>
-        <translation>Werkzeugleisten-Menu</translation>
+        <source>Bookmarks Toolbar</source>
+        <translation>Lesezeichenleiste</translation>
     </message>
     <message>
         <source>Bookmarks Menu</source>
@@ -331,7 +327,9 @@ Grund:
                            file.
 -setCurrentFilter filter   Set the filter as the active filter.
 -remove-search-index       Removes the full text search index.
--rebuild-search-index      Re-builds the full text search index (potentially slow).
+-rebuild-search-index      Obsolete. Use -remove-search-index instead.
+                           Removes the full text search index.
+                           It will be rebuilt on next Assistant run.
 -quiet                     Does not display any error or
                            status message.
 -help                      Displays this help.
@@ -361,7 +359,9 @@ Grund:
                            file.
 -setCurrentFilter filter   Set the filter as the active filter.
 -remove-search-index       Removes the full text search index.
--rebuild-search-index      Re-builds the full text search index (potentially slow).
+-rebuild-search-index      Obsolete. Use -remove-search-index instead.
+                           Removes the full text search index.
+                           It will be rebuilt on next Assistant run.
 -quiet                     Does not display any error or
                            status message.
 -help                      Displays this help.
@@ -686,6 +686,10 @@ Grund:
         <source>Ctrl+Alt+Left</source>
         <translation>Ctrl+Alt+Left</translation>
     </message>
+    <message>
+        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
+        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</translation>
+    </message>
     <message>
         <source>Could not register file &apos;%1&apos;: %2</source>
         <translation>Die Datei &apos;%1&apos; konnte nicht registriert werden: %2</translation>
@@ -738,10 +742,6 @@ Grund:
         <source>Could not find the associated content item.</source>
         <translation>Der zugehörige Inhaltseintrag konnte nicht gefunden werden.</translation>
     </message>
-    <message>
-        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</source>
-        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).&lt;/p&gt;</translation>
-    </message>
     <message>
         <source>About %1</source>
         <translation>Über %1</translation>
@@ -951,6 +951,10 @@ Grund:
         <source>Show tabs for each individual page</source>
         <translation>Reiter für jede einzelne Seite anzeigen</translation>
     </message>
+    <message>
+        <source>&lt;Filter&gt;</source>
+        <translation>&lt;Filter&gt;</translation>
+    </message>
 </context>
 <context>
     <name>RemoteControl</name>
