@@ -31,6 +31,14 @@
         <source>Duplicate default property</source>
         <translation>Mehrfaches Auftreten der Vorgabe-Eigenschaft</translation>
     </message>
+    <message>
+        <source>Duplicate alias name</source>
+        <translation>Mehrfaches Auftreten eines Aliasnamens</translation>
+    </message>
+    <message>
+        <source>Alias names cannot begin with an upper case letter</source>
+        <translation>Aliasnamen dürfen nicht mit einem Großbuchstaben beginnen</translation>
+    </message>
     <message>
         <source>Property value set multiple times</source>
         <translation>Mehrfache Zuweisung eines Wertes an eine Eigenschaft</translation>
@@ -73,6 +81,10 @@
         <source>id is not unique</source>
         <translation>Id-Wert nicht eindeutig</translation>
     </message>
+    <message>
+        <source>Circular alias reference detected</source>
+        <translation>Zirkuläre Referenzierung eines Alias festgestellt</translation>
+    </message>
     <message>
         <source>Invalid alias reference. Unable to find id &quot;%1&quot;</source>
         <translation>Ungültige Referenzierung einer Alias-Eigenschaft. Der Id-Wert &quot;%1&quot; konnte nicht gefunden werden</translation>
@@ -398,6 +410,10 @@
         <source>SQL: can&apos;t create database, offline storage is disabled.</source>
         <translation>SQL: Es kann keine Datenbank erstellt werden, offline storage ist deaktiviert.</translation>
     </message>
+    <message>
+        <source>LocalStorage: can&apos;t create path %1</source>
+        <translation>LocalStorage: Der Pfad %1 kann nicht angelegt werden</translation>
+    </message>
     <message>
         <source>SQL: database version mismatch</source>
         <translation>SQL: Die Version der Datenbank entspricht nicht der erwarteten Version</translation>
@@ -504,10 +520,6 @@
         <source>Module namespace &apos;%1&apos; does not match import URI &apos;%2&apos;</source>
         <translation>Der Modul-Namensraum &apos;%1&apos; entspricht nicht dem Import-URI &apos;%2&apos;</translation>
     </message>
-    <message>
-        <source>library loading is disabled</source>
-        <translation>Das Laden von Bibliotheken ist deaktiviert</translation>
-    </message>
     <message>
         <source>Namespace &apos;%1&apos; has already been used for type registration</source>
         <translation>Der Namensraum &apos;%1&apos; wurde bereits zur Typregistrierung verwendet</translation>
@@ -789,7 +801,7 @@
     </message>
 </context>
 <context>
-    <name>QQmlPropertyCacheCreator</name>
+    <name>QQmlPropertyCacheCreatorBase</name>
     <message>
         <source>Fully dynamic types cannot declare new properties.</source>
         <translation>Vollständig dynamische Typen können keine neuen Eigenschaften deklarieren.</translation>
@@ -804,7 +816,7 @@
     </message>
     <message>
         <source>Non-existent attached object</source>
-        <translation>Es existiert kein Bezugselement für die Eigenschaft</translation>
+        <translation>Das Objekt des Typs &apos;attached&apos; existiert nicht</translation>
     </message>
     <message>
         <source>Cannot override FINAL property</source>
@@ -953,6 +965,10 @@
         <source>Invalid property assignment: boolean expected</source>
         <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein boolescher Wert erwartet</translation>
     </message>
+    <message>
+        <source>Invalid property assignment: 2D vector expected</source>
+        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein zweidimensionaler Vektor erwartet</translation>
+    </message>
     <message>
         <source>Invalid property assignment: 3D vector expected</source>
         <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein dreidimensionaler Vektor erwartet</translation>
@@ -961,6 +977,10 @@
         <source>Invalid property assignment: 4D vector expected</source>
         <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein vierdimensionaler Vektor erwartet</translation>
     </message>
+    <message>
+        <source>Invalid property assignment: quaternion expected</source>
+        <translation>Ungültige Zuweisung bei Eigenschaft: Es wird eine Quaternion erwartet</translation>
+    </message>
     <message>
         <source>Invalid property assignment: regular expression expected; use /pattern/ syntax</source>
         <translation>Ungültige Zuweisung bei Eigenschaft: Es wird ein regulärer Ausdruck erwartet; verwenden Sie die Schreibweise /Muster/</translation>
@@ -1022,7 +1042,7 @@
     </message>
 </context>
 <context>
-    <name>QQmlTypeCompiler</name>
+    <name>QQmlTypeData</name>
     <message>
         <source>Composite Singleton Type %1 is not creatable.</source>
         <translation>Es kann kein Composite Singleton des Typs %1 erzeugt werden.</translation>
@@ -1058,6 +1078,10 @@
         <source>qmldir defines type as singleton, but no pragma Singleton found in type %1.</source>
         <translation>qmldir definiert den Typ als Singleton, aber der Typ %1 enthält kein pragma Singleton.</translation>
     </message>
+    <message>
+        <source>No such file or directory</source>
+        <translation>Die Datei oder das Verzeichnis konnte nicht gefunden werden</translation>
+    </message>
     <message>
         <source>module &quot;%1&quot; is not installed</source>
         <translation>Modul &quot;%1&quot; ist nicht installiert</translation>
@@ -1209,6 +1233,13 @@
         <translation>&apos;back&apos; kann nur einmal zugewiesen werden</translation>
     </message>
 </context>
+<context>
+    <name>QQuickGraphicsInfo</name>
+    <message>
+        <source>GraphicsInfo is only available via attached properties</source>
+        <translation>Auf GraphicsInfo kann nur mittels Eigenschaften des Typs &apos;attached&apos; zugegriffen werden</translation>
+    </message>
+</context>
 <context>
     <name>QQuickItemView</name>
     <message>
@@ -1236,14 +1267,14 @@
 </context>
 <context>
     <name>QQuickLayoutMirroringAttached</name>
-    <message>
-        <source>LayoutDirection attached property only works with Items</source>
-        <translation>LayoutDirection-Eigenschaften des Typs &apos;attached&apos; können nur mit Elementen der Klasse Item verwendet werden</translation>
-    </message>
     <message>
         <source>LayoutMirroring is only available via attached properties</source>
         <translation>LayoutMirroring ist nur in Verbindung mit Eigenschaften des Typs &quot;attached&quot; möglich</translation>
     </message>
+    <message>
+        <source>LayoutDirection attached property only works with Items and Windows</source>
+        <translation>Die Eigenschaft LayoutDirection des Typs &apos;attached&apos; funktioniert nur mit Objekten des Typs Item oder Window</translation>
+    </message>
 </context>
 <context>
     <name>QQuickLoader</name>
@@ -1394,6 +1425,13 @@
         <translation>Cursor-Delegate konnte nicht geladen werden</translation>
     </message>
 </context>
+<context>
+    <name>QQuickTouchPoint</name>
+    <message>
+        <source>PointingDeviceUniqueId is only available via read-only properties</source>
+        <translation>PointingDeviceUniqueId ist nur über schreibgeschützte Eigenschaften verfügbar</translation>
+    </message>
+</context>
 <context>
     <name>QQuickViewTransitionAttached</name>
     <message>
@@ -1489,6 +1527,10 @@ Installieren Sie einen Treiber, der OpenGL 2.0 oder neuer bereitstellt, oder ste
 </context>
 <context>
     <name>SignalTransition</name>
+    <message>
+        <source>Specified signal does not exist.</source>
+        <translation>Das angegebene Signal existiert nicht.</translation>
+    </message>
     <message>
         <source>Cannot assign to non-existent property &quot;%1&quot;</source>
         <translation>Es kann keine Zuweisung erfolgen, da keine Eigenschaft des Namens &quot;%1&quot; existiert</translation>
